==> nextcloud-app-spreed-1%3A18.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/af.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Gas",
    "File is too big" : "Lêer is te groot",
    "Invalid file provided" : "Ongeldige lêer verskaf",
    "Invalid image" : "Ongeldige beeld",
    "Unknown filetype" : "Onbekende lêertipe",
    "Accept" : "Aanvaar",
    "Open settings" : "Open instellings",
    "error" : "fout",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Verenigde Arabiese Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua en Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentinië",
    "American Samoa" : "Amerikaans-Samoa",
    "Austria" : "Oostenryk",
    "Australia" : "Australië",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandeilande",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegovina" : "Bosnië-Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesj",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarye",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sint Bartholomeus",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Broenei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint-Eustatius en Saba",
    "Brazil" : "Brasilië",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoetan",
    "Bouvet Island" : "Bouveteiland",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos- (Keeling-) eilande",
    "Central African Republic" : "Sentraal Afrikaanse Republiek",
    "Congo" : "Kongo",
    "Switzerland" : "Switserland",
    "Côte d'Ivoire" : "Ivoorkus",
    "Cook Islands" : "Cookeilande",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "Sjina",
    "Colombia" : "Colombië",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kaap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Kerseiland",
    "Cyprus" : "Siprus",
    "Czechia" : "Tsjeggië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djiboeti",
    "Denmark" : "Denemarke",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikaanse Republiek",
    "Algeria" : "Algerië",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egipte",
    "Western Sahara" : "Wes-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "Falkland Islands (Malvinas)" : "Falklandeilande (Malvinas)",
    "Faroe Islands" : "Faroëreilande",
    "France" : "Frankryk",
    "Gabon" : "Gaboen",
    "United Kingdom of Great Britain and Northern Ireland" : "Verenigde Koninkryk van Groot-Brittanje en Noord-Ierland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgië",
    "French Guiana" : "Frans-Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambië",
    "Guinea" : "Guinee",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekwatoriaal Guinee",
    "Greece" : "Griekeland",
    "South Georgia and the South Sandwich Islands" : "Suid-Georgië en die Suidelike Sandwicheilande",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinee-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heardeiland en McDonaldeilande",
    "Honduras" : "Honduras",
    "Croatia" : "Kroasië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarye",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "Isle of Man" : "Man, die eiland",
    "India" : "Indië",
    "British Indian Ocean Territory" : "Britse Indiese Oseaangebied",
    "Iraq" : "Irak",
    "Iceland" : "Ysland",
    "Italy" : "Italië",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisië",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "Sint Kitts en Nevis",
    "Kuwait" : "Koeweit",
    "Cayman Islands" : "Kaaimanseilande",
    "Kazakhstan" : "Kazakstan",
    "Lao People's Democratic Republic" : "Laos Demokratiese Volksrepubliek",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberië",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litaue",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sint Martin (Franse deel)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalleilande",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolië",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Noordelike Marianaeilande",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritanië",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maledive",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mosambiek",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieu-Kaledonië",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkeiland",
    "Nigeria" : "Nigerië",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorweë",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nieu-Seeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Frans-Polinesië",
    "Papua New Guinea" : "Papoea-Nieu-Guinee",
    "Philippines" : "Filippyne",
    "Pakistan" : "Pakistan",
    "Poland" : "Pole",
    "Saint Pierre and Miquelon" : "Sint Pierre en Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina (omstrede gebied)",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Roemenië",
    "Serbia" : "Serwië",
    "Russian Federation" : "Russiese Federasie",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Solomoneilande",
    "Seychelles" : "Seychelle",
    "Sudan" : "Seodan",
    "Sweden" : "Swede",
    "Singapore" : "Singapoer",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sint Helena, Ascension en Tristan da Cunha",
    "Slovenia" : "Slowenië",
    "Svalbard and Jan Mayen" : "Spitsbergen en Jan Mayen",
    "Slovakia" : "Slowakye",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Suid-Soedan",
    "Sao Tome and Principe" : "São Tomé en Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Nederlandse deel)",
    "Syrian Arab Republic" : "Siriese Arabiese Republiek",
    "Turks and Caicos Islands" : "Turks- en Caicoseilande",
    "Chad" : "Tsjad",
    "French Southern Territories" : "Franse Suidelike en Antarktiese Gebiede",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Oos-Timor",
    "Turkmenistan" : "Turkmenië",
    "Tunisia" : "Tunisië",
    "Tonga" : "Tonga",
    "Turkey" : "Turkye",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzanië, Verenigde Republiek van",
    "Ukraine" : "Oekraïne",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Klein Afgeleë Eilande van die Verenigde State van Amerika",
    "United States of America" : "Verenigde State van Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oesbekistan",
    "Holy See" : "Vatikaanstad",
    "Saint Vincent and the Grenadines" : "Sint Vincent en die Grenadine",
    "Viet Nam" : "Viëtnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis en Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suid-Afrika",
    "Zambia" : "Zambië",
    "Zimbabwe" : "Zimbabwe",
    "Everyone" : "Almal",
    "Save changes" : "Bewaar veranderinge",
    "Saving …" : "Word gestoor …",
    "Saved!" : "Gestoor!",
    "Name" : "Naam",
    "Description" : "Beskrywing",
    "None" : "Geen",
    "User" : "Gebruiker",
    "Users" : "Gebruikers",
    "All messages" : "Alle boodskappe",
    "Off" : "Af",
    "Language" : "Taal",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Geskep om",
    "Pending" : "Hangend",
    "Error" : "Fout",
    "Active" : "Aktief",
    "OK" : "Goed",
    "Checking …" : "Gaan tans na …",
    "Back" : "Terug",
    "Cancel" : "Kanselleer",
    "Confirm" : "Bevestig",
    "Reset" : "Herstel",
    "Copy link" : "Kopieer skakel",
    "You" : "U",
    "Collapse" : "Vou In",
    "This conversation is read-only" : "Hierdie gesprek is leesalleen",
    "Favorite" : "Gunsteling",
    "Disable" : "Deaktiveer",
    "Choose" : "Kies",
    "Personal" : "Persoonlik",
    "Leave conversation" : "verlaat gesprek",
    "Delete conversation" : "Skrap gesprek",
    "Save" : "Stoor",
    "Edit" : "Wysig",
    "Delete" : "Skrap",
    "Password" : "Wagwoord",
    "Login" : "Teken aan",
    "Nickname" : "Bynaam",
    "Client ID" : "Kliënt-ID",
    "Notifications" : "Kennisgewings",
    "Remove from favorites" : "Verwyder uit gunstelinge",
    "Add to favorites" : "Voeg by gunstelinge",
    "Groups" : "Groepe",
    "Loading" : "Laai tans..",
    "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
    "Devices" : "Toestelle",
    "Upload" : "Oplaai",
    "Files" : " Lêers",
    "Reply" : "Antwoord",
    "Dismiss" : "Ontslaan",
    "Contact" : "Kontak",
    "Today" : "Vandag",
    "Yesterday" : "Gister",
    "Add participants" : "Voeg deelnemers toe",
    "Close" : "Sluit",
    "Password protect" : "Beskerm met 'n wagwoord",
    "Enter password" : "Voer wagwoord in",
    "Group" : "Groep",
    "Settings" : "Instellings",
    "Send" : "Stuur",
    "Join" : "Sluit aan",
    "guest" : "gas",
    "Promote to moderator" : "Bevorder na moderator",
    "Remove participant" : "Verwyder deelnemer",
    "Chat" : "Klets",
    "Details" : "Besonderhede",
    "Privacy" : "Privaatheid",
    "Keyboard shortcuts" : "Sneltoetse",
    "Search" : "Soek",
    "Open sidebar" : "Open kantbalk",
    "Select a region" : "Kies ’n streek",
    "Submit" : "Dien in",
    "Media" : "Media",
    "Audio" : "Oudio",
    "Other" : "Ander",
    "Do not disturb" : "Moenie pla nie",
    "Away" : "Weg",
    "Default" : "Verstek",
    "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
    "Android app" : "Android-toep",
    "iOS app" : "iOS-toep"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A20.0.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/af.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Gas",
    "File is too big" : "Lêer is te groot",
    "Invalid file provided" : "Ongeldige lêer verskaf",
    "Invalid image" : "Ongeldige beeld",
    "Unknown filetype" : "Onbekende lêertipe",
    "Accept" : "Aanvaar",
    "Open settings" : "Open instellings",
    "error" : "fout",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Verenigde Arabiese Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua en Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentinië",
    "American Samoa" : "Amerikaans-Samoa",
    "Austria" : "Oostenryk",
    "Australia" : "Australië",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandeilande",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegovina" : "Bosnië-Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesj",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarye",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sint Bartholomeus",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Broenei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint-Eustatius en Saba",
    "Brazil" : "Brasilië",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoetan",
    "Bouvet Island" : "Bouveteiland",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos- (Keeling-) eilande",
    "Central African Republic" : "Sentraal Afrikaanse Republiek",
    "Congo" : "Kongo",
    "Switzerland" : "Switserland",
    "Côte d'Ivoire" : "Ivoorkus",
    "Cook Islands" : "Cookeilande",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "Sjina",
    "Colombia" : "Colombië",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kaap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Kerseiland",
    "Cyprus" : "Siprus",
    "Czechia" : "Tsjeggië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djiboeti",
    "Denmark" : "Denemarke",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikaanse Republiek",
    "Algeria" : "Algerië",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egipte",
    "Western Sahara" : "Wes-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "Falkland Islands (Malvinas)" : "Falklandeilande (Malvinas)",
    "Faroe Islands" : "Faroëreilande",
    "France" : "Frankryk",
    "Gabon" : "Gaboen",
    "United Kingdom of Great Britain and Northern Ireland" : "Verenigde Koninkryk van Groot-Brittanje en Noord-Ierland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgië",
    "French Guiana" : "Frans-Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambië",
    "Guinea" : "Guinee",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekwatoriaal Guinee",
    "Greece" : "Griekeland",
    "South Georgia and the South Sandwich Islands" : "Suid-Georgië en die Suidelike Sandwicheilande",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinee-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heardeiland en McDonaldeilande",
    "Honduras" : "Honduras",
    "Croatia" : "Kroasië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarye",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "Isle of Man" : "Man, die eiland",
    "India" : "Indië",
    "British Indian Ocean Territory" : "Britse Indiese Oseaangebied",
    "Iraq" : "Irak",
    "Iceland" : "Ysland",
    "Italy" : "Italië",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisië",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "Sint Kitts en Nevis",
    "Kuwait" : "Koeweit",
    "Cayman Islands" : "Kaaimanseilande",
    "Kazakhstan" : "Kazakstan",
    "Lao People's Democratic Republic" : "Laos Demokratiese Volksrepubliek",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberië",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litaue",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sint Martin (Franse deel)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalleilande",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolië",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Noordelike Marianaeilande",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritanië",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maledive",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mosambiek",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieu-Kaledonië",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkeiland",
    "Nigeria" : "Nigerië",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorweë",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nieu-Seeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Frans-Polinesië",
    "Papua New Guinea" : "Papoea-Nieu-Guinee",
    "Philippines" : "Filippyne",
    "Pakistan" : "Pakistan",
    "Poland" : "Pole",
    "Saint Pierre and Miquelon" : "Sint Pierre en Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina (omstrede gebied)",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Roemenië",
    "Serbia" : "Serwië",
    "Russian Federation" : "Russiese Federasie",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Solomoneilande",
    "Seychelles" : "Seychelle",
    "Sudan" : "Seodan",
    "Sweden" : "Swede",
    "Singapore" : "Singapoer",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sint Helena, Ascension en Tristan da Cunha",
    "Slovenia" : "Slowenië",
    "Svalbard and Jan Mayen" : "Spitsbergen en Jan Mayen",
    "Slovakia" : "Slowakye",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Suid-Soedan",
    "Sao Tome and Principe" : "São Tomé en Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Nederlandse deel)",
    "Syrian Arab Republic" : "Siriese Arabiese Republiek",
    "Turks and Caicos Islands" : "Turks- en Caicoseilande",
    "Chad" : "Tsjad",
    "French Southern Territories" : "Franse Suidelike en Antarktiese Gebiede",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Oos-Timor",
    "Turkmenistan" : "Turkmenië",
    "Tunisia" : "Tunisië",
    "Tonga" : "Tonga",
    "Turkey" : "Turkye",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzanië, Verenigde Republiek van",
    "Ukraine" : "Oekraïne",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Klein Afgeleë Eilande van die Verenigde State van Amerika",
    "United States of America" : "Verenigde State van Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oesbekistan",
    "Holy See" : "Vatikaanstad",
    "Saint Vincent and the Grenadines" : "Sint Vincent en die Grenadine",
    "Viet Nam" : "Viëtnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis en Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suid-Afrika",
    "Zambia" : "Zambië",
    "Zimbabwe" : "Zimbabwe",
    "Everyone" : "Almal",
    "Save changes" : "Bewaar veranderinge",
    "Saving …" : "Word gestoor …",
    "Saved!" : "Gestoor!",
    "Name" : "Naam",
    "Description" : "Beskrywing",
    "All messages" : "Alle boodskappe",
    "Off" : "Af",
    "Language" : "Taal",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Geskep om",
    "Pending" : "Hangend",
    "Error" : "Fout",
    "Active" : "Aktief",
    "OK" : "Goed",
    "Checking …" : "Gaan tans na …",
    "Back" : "Terug",
    "Cancel" : "Kanselleer",
    "Confirm" : "Bevestig",
    "Reset" : "Herstel",
    "Copy link" : "Kopieer skakel",
    "This conversation is read-only" : "Hierdie gesprek is leesalleen",
    "You" : "U",
    "Collapse" : "Vou In",
    "Favorite" : "Gunsteling",
    "Disable" : "Deaktiveer",
    "Choose" : "Kies",
    "Personal" : "Persoonlik",
    "Leave conversation" : "verlaat gesprek",
    "Delete conversation" : "Skrap gesprek",
    "Save" : "Stoor",
    "Edit" : "Wysig",
    "Delete" : "Skrap",
    "User" : "Gebruiker",
    "Password" : "Wagwoord",
    "Login" : "Teken aan",
    "Nickname" : "Bynaam",
    "Client ID" : "Kliënt-ID",
    "Notifications" : "Kennisgewings",
    "Remove from favorites" : "Verwyder uit gunstelinge",
    "Add to favorites" : "Voeg by gunstelinge",
    "Users" : "Gebruikers",
    "Groups" : "Groepe",
    "Loading" : "Laai tans..",
    "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
    "None" : "Geen",
    "Devices" : "Toestelle",
    "Upload" : "Oplaai",
    "Files" : " Lêers",
    "Reply" : "Antwoord",
    "Dismiss" : "Ontslaan",
    "Contact" : "Kontak",
    "Today" : "Vandag",
    "Yesterday" : "Gister",
    "Add participants" : "Voeg deelnemers toe",
    "Close" : "Sluit",
    "Password protect" : "Beskerm met 'n wagwoord",
    "Enter password" : "Voer wagwoord in",
    "Group" : "Groep",
    "Settings" : "Instellings",
    "Send" : "Stuur",
    "Join" : "Sluit aan",
    "guest" : "gas",
    "Promote to moderator" : "Bevorder na moderator",
    "Remove participant" : "Verwyder deelnemer",
    "Chat" : "Klets",
    "Details" : "Besonderhede",
    "Privacy" : "Privaatheid",
    "Keyboard shortcuts" : "Sneltoetse",
    "Search" : "Soek",
    "Select a region" : "Kies ’n streek",
    "Submit" : "Dien in",
    "Media" : "Media",
    "Audio" : "Oudio",
    "Other" : "Ander",
    "Do not disturb" : "Moenie pla nie",
    "Away" : "Weg",
    "Default" : "Verstek",
    "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
    "Android app" : "Android-toep",
    "iOS app" : "iOS-toep",
    "Open sidebar" : "Open kantbalk"
},
"nplurals=2; plural=(n != 1);");
